##  Global Filter
The global filter applies to all fact sheet types used in KPI calculations. It supports the following attributes:
  * Fact sheet statuses
  * Quality seal states


By default, all values are selected, meaning no filter is applied. You can adjust the global filter by selecting relevant values.
